from pydantic import BaseModel
from .agents import {{crew_name}}Agents
from .tasks import {{crew_name}}Tasks

from crewai import Crew, Process

class {{crew_name}}Crew(BaseModel):
	"""{{crew_name}} crew."""
	agents = {{crew_name}}Agents()
	tasks = {{crew_name}}Tasks()

	def crew(self):
		"""Kick off the {{crew_name}} crew."""
		return Crew(
			agents=self.agents.agents(),
			tasks=self.tasks.tasks(),
			process=Process.sequential,
			verbose=2
		)


import inspect
from crewai import Agent

class {{crew_name}}Agents:
	"""Agents for your {{crew_name}} crew."""

	# Your agents defined here
	def your_agent(self):
		"""Create your first agent for {{crew_name}}."""
		return Agent(
			role="Agent Role",
			goal="Agent Goal",
			backstory="Agent Backstory"
		)


import click
from .create_crew import create_crew

@click.group()
def crewai():
	"""Top-level command group for crewai."""
	pass

@crewai.command()
@click.argument('project_name')
def create(project_name):
	"""Create a new crew."""
	create_crew(project_name)

if __name__ == "__main__":
	crewai()



from .agents import {{crew_name}}Agents
from crewai import Task

class {{crew_name}}Tasks:
	"""Tasks for your {{crew_name}} crew."""
	agents = {{crew_name}}Agents()

	# Your tasks defined here
	def your_task(self):
		"""Create your first task for {{crew_name}}."""
		return Task(
			description="Task Description",
			expected_output="Expected Output from task",
			agent=self.agents.your_agent()
		)